@@ -88,17 +88,19 @@ class PayerType(Enum):
 
 class PaymentDataSplit(BaseModel):
     code: str
-    amount: condecimal(max_digits=12, decimal_places=2)
+    amount: condecimal(ge=Decimal('0'), max_digits=12, decimal_places=2) | None = None
     meta: dict
 
     @validator('amount', pre=True)
     def _parse_split_amount(cls, v):
-        if v is None:
-            return v
+        if v in (None, ''):
+            return None
         return Decimal(str(v)).quantize(Decimal('0.01'), rounding=ROUND_HALF_UP)
 
     @property
     def amount_cents(self) -> int:
+        if self.amount is None:
+            return 0
         return int((self.amount * 100).quantize(Decimal('1'), rounding=ROUND_HALF_UP))
 
     def json(self):
@@ -141,7 +143,7 @@ class PaymentData(BaseModel):
     transaction_id: Optional[str]
     paid_at: Optional[datetime.datetime]
     expire_at: Optional[datetime.datetime]
-    amount: Optional[condecimal(max_digits=12, decimal_places=2)]
+    amount: Optional[condecimal(ge=Decimal('0'), max_digits=12, decimal_places=2)] | None = None
     currency: CurrencyType
     type: Optional[PaymentType]
     notice_code: Optional[str]
@@ -162,8 +164,8 @@ class PaymentData(BaseModel):
 
     @validator('amount', pre=True)
     def _parse_amount(cls, v):
-        if v is None:
-            return v
+        if v in (None, ''):
+            return None
         return Decimal(str(v)).quantize(Decimal('0.01'), rounding=ROUND_HALF_UP)
 
     @property
